@@ -1,4 +1,4 @@
-/// Assert two bags are not equal.
+/// Assert a bag is not equal to another.
 ///
 /// * When true, return `()`.
 ///
@@ -8,16 +8,26 @@
 /// # Examples
 ///
 /// ```rust
-/// # #[macro_use] extern crate assertables; fn main() {
-/// assert_bag_ne!([1, 1], [1, 1, 1]);
+/// # #[macro_use] extern crate assertables;
+/// # use std::panic;
+/// # fn main() {
+/// let a = [1, 1];
+/// let b = [1, 1, 1];
+/// assert_bag_ne!(&a, &b);
 /// //-> ()
-/// # }
-/// ```
 ///
-/// ```rust
-/// # #[macro_use] extern crate assertables; fn main() {
-/// // assert_bag_ne!([1, 1], [1, 1]);
-/// //-> panic!("assertion failed: `assert_bag_ne(left, right)`\n  left: `[1, 1]`\n right: `[1, 1]`")
+/// # let result = panic::catch_unwind(|| {
+/// let a = [1, 1];
+/// let b = [1, 1];
+/// assert_bag_ne!(&a, &b);
+/// //-> panic!("…")
+/// // assertion failed: `assert_bag_ne!(left, right)`
+/// //   left: `[1, 1]`,
+/// //  right: `[1, 1]`
+/// # });
+/// # let actual = result.unwrap_err().downcast::<String>().unwrap().to_string();
+/// # let expect = "assertion failed: `assert_bag_ne!(left, right)`\n  left: `[1, 1]`,\n right: `[1, 1]`";
+/// # assert_eq!(actual, expect);
 /// # }
 /// ```
 ///
@@ -42,7 +52,7 @@ macro_rules! assert_bag_ne {
                 if left_bag != right_bag {
                     ()
                 } else {
-                    panic!("assertion failed: `assert_bag_ne(left, right)`\n  left: `{:?}`\n right: `{:?}`", $left, $right)
+                    panic!("assertion failed: `assert_bag_ne!(left, right)`\n  left: `{:?}`,\n right: `{:?}`", $left, $right)
                 }
             }
         }
@@ -78,18 +88,15 @@ mod tests {
         let a = [1, 1];
         let b = [1, 1, 1];
         let x = assert_bag_ne!(&a, &b);
-        assert_eq!(
-            x,
-            ()
-        );
+        assert_eq!(x, ());
     }
 
     #[test]
-    #[should_panic (expected = "assertion failed: `assert_bag_ne(left, right)`\n  left: `[1, 1]`\n right: `[1, 1]`")]
+    #[should_panic (expected = "assertion failed: `assert_bag_ne!(left, right)`\n  left: `[1, 1]`,\n right: `[1, 1]`")]
     fn test_assert_bag_ne_x_arity_2_failure() {
         let a = [1, 1];
         let b = [1, 1];
-        let _ = assert_bag_ne!(&a, &b);
+        let _x = assert_bag_ne!(&a, &b);
     }
 
     #[test]
@@ -97,10 +104,7 @@ mod tests {
         let a = [1, 1];
         let b = [1, 1, 1];
         let x = assert_bag_ne!(&a, &b, "message");
-        assert_eq!(
-            x,
-            ()
-        );
+        assert_eq!(x, ());
     }
 
     #[test]
@@ -108,7 +112,7 @@ mod tests {
     fn test_assert_bag_ne_x_arity_3_failure() {
         let a = [1, 1];
         let b = [1, 1];
-        let _ = assert_bag_ne!(&a, &b, "message");
+        let _x = assert_bag_ne!(&a, &b, "message");
     }
 
 }
