@@ -1,4 +1,4 @@
-/// Assert one value is greater than another value.
+/// Assert a value is greater than another.
 ///
 /// * When true, return `()`.
 ///
@@ -8,16 +8,22 @@
 /// # Examples
 ///
 /// ```rust
-/// # #[macro_use] extern crate assertables; fn main() {
+/// # #[macro_use] extern crate assertables;
+/// # use std::panic;
+/// # fn main() {
 /// assert_gt!(2, 1);
 /// //-> ()
-/// # }
-/// ```
 ///
-/// ```rust
-/// # #[macro_use] extern crate assertables; fn main() {
-/// // assert_gt!(1, 2);
-/// //-> panic!("assertion failed: `assert_gt(left, right)`\n  left: `2`\n right: `1`")
+/// # let result = panic::catch_unwind(|| {
+/// assert_gt!(1, 2);
+/// //-> panic!
+/// // assertion failed: `assert_gt!(left, right)`
+/// //   left: `1`,
+/// //  right: `2`
+/// # });
+/// # let actual = result.unwrap_err().downcast::<String>().unwrap().to_string();
+/// # let expect = "assertion failed: `assert_gt!(left, right)`\n  left: `1`,\n right: `2`";
+/// # assert_eq!(actual, expect);
 /// # }
 /// ```
 ///
@@ -30,7 +36,7 @@ macro_rules! assert_gt {
                 if (left_val > right_val) {
                     ()
                 } else {
-                    panic!("assertion failed: `assert_gt(left, right)`\n  left: `{:?}`\n right: `{:?}`", $left, $right);
+                    panic!("assertion failed: `assert_gt!(left, right)`\n  left: `{:?}`,\n right: `{:?}`", $left, $right);
                 }
             }
         }
@@ -56,18 +62,15 @@ mod tests {
         let a = 2;
         let b = 1;
         let x = assert_gt!(a, b);
-        assert_eq!(
-            x,
-            ()
-        );
+        assert_eq!(x, ());
     }
 
     #[test]
-    #[should_panic (expected = "assertion failed: `assert_gt(left, right)`\n  left: `1`\n right: `2`")]
+    #[should_panic (expected = "assertion failed: `assert_gt!(left, right)`\n  left: `1`,\n right: `2`")]
     fn test_assert_gt_x_arity_2_failure() {
         let a = 1;
         let b = 2;
-        let _ = assert_gt!(a, b);
+        let _x = assert_gt!(a, b);
     }
 
     #[test]
@@ -75,10 +78,7 @@ mod tests {
         let a = 2;
         let b = 1;
         let x = assert_gt!(a, b, "message");
-        assert_eq!(
-            x,
-            ()
-        );
+        assert_eq!(x, ());
     }
 
     #[test]
@@ -86,7 +86,7 @@ mod tests {
     fn test_assert_gt_x_arity_3_failure() {
         let a = 1;
         let b = 2;
-        let _ = assert_gt!(a, b, "message");
+        let _x = assert_gt!(a, b, "message");
     }
 
 }
